@@ -32,6 +32,7 @@ class Database:
             
             response = requests.get(link_str)
 
+            
             if price_adj == False:
                 ohlc_result = json.loads(json.loads(response.content).replace("'", "\""))
             else:
@@ -125,6 +126,7 @@ class Database:
                        end_date_str
 
             response = requests.get(link_str)
+            print(response)
             #result = ast.literal_eval(json.loads(response.content))
             result = json.loads(json.loads(response.content).replace("'", "\""))
 
@@ -284,7 +286,7 @@ class Database:
                     err_msg += error + ','
             print(err_msg)
 
-    def get_hk_market_cap_hist(self, start_date, end_date):
+    def get_hk_market_cap_hist_by_date(self, start_date, end_date):
         
         check_bool_dict = self.check_start_end_date(start_date, end_date)
 
@@ -314,6 +316,9 @@ class Database:
 
             df = df.sort_values(['date', 'market_cap_mil'], ascending=[True, False])
             df = df.reset_index(drop=True)
+            df['date'] = pd.to_datetime(df['date'],format='%Y-%m-%d')
+            #df['record_date'] = pd.to_datetime(df['record_date'],format='%Y%m%d')
+            df = df[['date','code','issued_share_mil','market_cap_mil','cumulative_market_cap_mil']]
             return df
 
         else:
@@ -833,7 +838,7 @@ class Database:
 
         df = pd.DataFrame(result)
         df['ipo_date'] = pd.to_datetime(df['ipo_date'],format='%Y-%m-%d')
-        df['ipo_date'] = df['ipo_date'].astype(str)
+        #df['ipo_date'] = df['ipo_date'].astype(str)
 
         df['share_issued'] = df['share_issued'].astype(str)
         df['market_capital'] = df['market_capital'].astype(str)
@@ -843,7 +848,8 @@ class Database:
         
         df['share_issued'] = df['share_issued'].astype(int)
         df['market_capital'] = df['market_capital'].astype(int)
-
+        
+        
         return df
 
     def get_hk_ipo_hist(self):
@@ -871,11 +877,16 @@ class Database:
                     df.at[i,col] = content[0:-1]
                 if 'Appraisaland' in content:
                     df.at[i,col] = content.replace('Appraisaland','Appraisal and')
-
+        
+        df['prospectus_date'] = pd.to_datetime(df['prospectus_date'], format='%d/%m/%Y')
+        df['listing_date'] = pd.to_datetime(df['listing_date'], format='%d/%m/%Y')
+        
         return df
 
-    def get_market_highlight(self, market, start_date, end_date):
-
+    def get_market_highlight(self, start_date, end_date):
+        
+        market = 'hk_main_board'
+        
         check_bool_dict = self.check_market_highlight_args(market, start_date, end_date)
 
         if False not in list(check_bool_dict.values()):
@@ -904,6 +915,9 @@ class Database:
             df = df.drop_duplicates(subset='date',keep='last')
             df = df.set_index(keys='date')
             df = df.sort_index()
+            
+            df = df.rename(columns={'average_pe_ratio_times':'average_pe_ratio'})
+            
             return df
 
         else:
@@ -941,6 +955,7 @@ class Database:
             df['date'] = pd.to_datetime(df['date'], format='%Y%m%d')
 
             df = df.set_index(keys='date')
+            #df = df.reset_index(drop=False)
             df = df.sort_index()
             return df
 
